FxHash

Struct FxHash 

pub struct FxHash { /* private fields */ }
Implementation of the FxHash algorithm.

This is a fast, non-cryptographic hash function, suitable for use in hash tables.

Implementations

Source

impl FxHash

pub const fn new() -> Self

Creates a new FxHash instance with the default initial state.

pub const fn with_seed(seed: u64) -> Self

Creates a new FxHash instance with the given seed.

pub const fn update_const(&mut self, data: &[u8])

Updates the internal state with the given data.

pub const fn result_const(&self) -> u64

Returns the final hash value.

This function does not update the internal state, and thus FxHash can still be used afterwards.

pub const fn clone_const(&self) -> Self

Clones the FxHash instance.