pub struct FxHash { /* private fields */ }Expand description
Implementation of the FxHash algorithm.
This is a fast, non-cryptographic hash function, suitable for use in hash tables.
Implementations
Sourceimpl FxHash
impl FxHash
Sourcepub const fn update_const(&mut self, data: &[u8])
pub const fn update_const(&mut self, data: &[u8])
Updates the internal state with the given data.
Sourcepub const fn result_const(&self) -> u64
pub const fn result_const(&self) -> u64
Returns the final hash value.
This function does not update the internal state, and thus
FxHash can still be used afterwards.
Sourcepub const fn clone_const(&self) -> Self
pub const fn clone_const(&self) -> Self
Clones the FxHash instance.